use std::path::PathBuf;

use eframe::egui;
use egui::*;
use renrs::{State, Command};

pub fn run(file: PathBuf) -> Result<(), eframe::Error> {
    env_logger::init();
    let options = eframe::NativeOptions {
        initial_window_size: Some(egui::vec2(640.0, 480.0)),
        resizable: false, // prevent i3 from automatically resizing
        ..Default::default()
    };
    eframe::run_native(
        "renrs-gui", 
        options,
        Box::new(|_cc| Box::new(
            App::from_state(State::from_file(file))
        )),
    )
}

struct App {
    state: State,
    text: String,
}

impl App {
    fn from_state(state: State) -> Self {
        let mut app = Self {
            state,
            text: "".to_owned(),
        };
        app.next();
        app
    }

    fn next(&mut self) {
        if let Some(Command::Say { name, text }) = self.state.next_command() {
            self.text = match name {
                Some(name) => format!("{name}: {text}"),
                None => text,
            }
        }
    }
}

impl eframe::App for App {
    fn update(&mut self, ctx: &egui::Context, _frame: &mut eframe::Frame) {
        egui::CentralPanel::default().show(ctx, |ui| {
            if ctx.input(|i|
                i.key_pressed(Key::Space)
                || i.pointer.button_clicked(PointerButton::Primary)
            ) {
                self.next();
            }
            ui.label(&self.text);
        });
    }
}